@@ -215,7 +215,7 @@ ScriptSymbols *ScriptInterp::getLocal(void)
 bool ScriptInterp::setConst(const char *id, const char *value)
 {
 	MutexLock lock(*this);
-	Symbol *sym = mapSymbol(id, strlen(value));
+	Symbol *sym = mapSymbol(id, (unsigned short)strlen(value));
 
 	if(!sym)
 		return false;
