@@ -37,6 +37,30 @@
 
 #include "engine.h"
 
+#if defined(_MSC_VER) && _MSC_VER >= 1300
+#if defined(_WIN64_) || defined(__WIN64__)
+#define RLL_SUFFIX ".x64"
+#elif defined(_M_IX86)
+#define RLL_SUFFIX ".x86"
+#else
+#define RLL_SUFFIX ".xlo"
+#endif
+#endif
+
+#if defined(__MINGW32__) | defined(__CYGWIN32__)
+#define RLL_SUFFIX ".dso"
+#endif
+
+#ifdef  W32
+#ifndef RLL_SUFFIX
+#define RLL_SUFFIX ".rll"
+#endif
+#endif
+
+#ifndef RLL_SUFFIX
+#define RLL_SUFFIX ".dso"
+#endif
+
 using namespace std;
 using namespace ost;
 
@@ -58,23 +82,21 @@ Script::Test *Script::test = NULL;
 Script::Fun *Script::ifun = NULL;
 Script::Package *Script::Package::first = NULL;
 
-class Registry : public Script
+class ScriptRegistry : public Script
 {
 public:
-	Registry();
+	ScriptRegistry();
 };
 
-static class Registry registry;
+static class ScriptRegistry registry;
 
 #if     defined(CAPE_REGISTRY_PREFIX) 
 #define REGISTRY_SCRIPT_SETTINGS CAPE_REGISTRY_PREFIX "\\Script Settings"
-#elif defined(_MSC_VER) && _MSC_VER >= 1300
-#define REGISTRY_SCRIPT_SETTINGS "SOFTWARE\\CAPE Framework .NET\\Script Settings"
 #else
 #define REGISTRY_SCRIPT_SETTINGS "SOFTWARE\\CAPE Framework\\Script Settings"
 #endif
 
-Registry::Registry() 
+ScriptRegistry::ScriptRegistry() 
 {
 #ifdef	WIN32
         static TCHAR regpath[256];
@@ -305,7 +327,7 @@ const char *Script::extract(Symbol *sym)
 		memcpy(&data, &sym->data[pos * sizeof(data)], sizeof(data));
 		if(++pos >= len)
 			pos = 0;
-		sym->data[sym->size] = pos;
+		sym->data[sym->size] = (unsigned char)pos;
 		return data;		
         case symFIFO:
 		if(a->head == a->tail)
@@ -371,7 +393,7 @@ bool Script::commit(Symbol *sym, const char *value)
 		{
 			dec = sym->size - 12;
 			snprintf(vbuf, sizeof(vbuf), "%ld", v2);
-			len = strlen(vbuf);
+			len = (unsigned short)strlen(vbuf);
 			sp = vbuf;
 			if(len > dec && vbuf[dec] >= '5')
 			{
@@ -391,7 +413,7 @@ bool Script::commit(Symbol *sym, const char *value)
 			}	
 			dec = sym->size - 12;
 			snprintf(sym->data, 12, "%ld", v1);
-                	len = strlen(sym->data);
+                	len = (unsigned short)strlen(sym->data);
 			sym->data[len++] = decimal;
 			dp = sym->data + len;
 			while(dec--)
@@ -411,7 +433,7 @@ bool Script::commit(Symbol *sym, const char *value)
 		}
 		if(sp && dp)
 		{
-			len = strlen(sp);
+			len = (unsigned short)strlen(sp);
 			if(len > sym->size - 12)
 				len = sym->size - 12;
 			memcpy(dp, sp, len);
@@ -483,10 +505,8 @@ retry:
 	if(strchr(name, ':'))
 		return false;
 
-	snprintf(buffer, sizeof(buffer), "%s/%s.rll", dpath, name);
-#else
-	snprintf(buffer, sizeof(buffer), "%s/%s.dso", dpath, name);
 #endif
+	snprintf(buffer, sizeof(buffer), "%s/%s" RLL_SUFFIX, dpath, name);
 	name = buffer;
 
 	while(pkg)
