@@ -275,7 +275,7 @@ ScriptRuntime()
 
 	Script::symsize = 64;
 	Script::pagesize = 1024;
-	Script::symlimit = Script::pagesize - 64;
+	Script::symlimit = (unsigned)Script::pagesize - 64;
 }
 
 #ifndef	WIN32
